#
# spec file for package linkerd-cli-edge
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define linkerd_executable_name linkerd

Name:           linkerd-cli-edge
Version:        25.5.1
Release:        1.1
Summary:        CLI for the linkerd service mesh for Kubernetes
License:        Apache-2.0
URL:            https://github.com/linkerd/linkerd2
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.22
BuildRequires:  zsh

# cannot be installed in parallel to the stable version
Conflicts:      linkerd-cli

%description
The Linkerd CLI is the primary way to interact with Linkerd. It can install the
control plane to your cluster, add the proxy to your service and provide
detailed metrics for how your service is performing.

Linkerd is an ultralight, security-first service mesh for Kubernetes. Linkerd
adds critical security, observability, and reliability features to your
Kubernetes stack with no code change required.

Linkerd is a Cloud Native Computing Foundation (CNCF) project.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
GO111MODULE=on go generate -mod=readonly ./pkg/charts/static
GO111MODULE=on go generate -mod=readonly ./jaeger/static
GO111MODULE=on go generate -mod=readonly ./multicluster/static
GO111MODULE=on go generate -mod=readonly ./viz/static
go build \
   -mod=vendor \
   -tags prod \
   -buildmode=pie \
   -ldflags="-X github.com/linkerd/linkerd2/pkg/version.Version=stable-%{version}" \
   -o bin/%{linkerd_executable_name} ./cli/

%install
# Install the binary.
install -D -m 0755 bin/%{linkerd_executable_name} %{buildroot}/%{_bindir}/%{linkerd_executable_name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{linkerd_executable_name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{linkerd_executable_name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{linkerd_executable_name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{linkerd_executable_name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Sat May  3 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 25.5.1:
  No CLI-related changes (other than dependencies)
  * build(deps): bump tokio-metrics from 0.4.1 to 0.4.2 (#13983)
  * build(deps): bump openssl-sys from 0.9.107 to 0.9.108 (#13984)
  * build(deps): bump sha2 from 0.10.8 to 0.10.9 (#13985)
  * build(deps): bump github.com/emicklei/proto from 1.14.0 to
    1.14.1 (#13978)
  * build(deps): bump chrono from 0.4.40 to 0.4.41 (#13977)
  * build(deps): bump getrandom from 0.2.15 to 0.2.16 (#13961)
  * build(deps): bump tokio-util from 0.7.14 to 0.7.15 (#13963)
  * build(deps): bump actions/download-artifact from 4.2.1 to 4.3.0
    (#13967)
  * build(deps-dev): bump webpack from 5.99.6 to 5.99.7 in /web/app
    (#13970)
  * build(deps): bump syn from 2.0.100 to 2.0.101 (#13971)
  * build(deps): bump cc from 1.2.19 to 1.2.20 (#13972)
  * build(deps): bump google-github-actions/auth from 2.1.8 to
    2.1.10 (#13973)
  * build(deps): bump tj-actions/changed-files (#13974)
  * build(deps): bump google.golang.org/grpc from 1.71.1 to 1.72.0
    (#13959)
  * build(deps): bump tokio-metrics from 0.4.0 to 0.4.1 (#13960)
* Thu Apr 24 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 25.4.4:
  * build(deps): bump libc from 0.2.171 to 0.2.172 (#13944)
  * proxy: v2.294.0 (#13958)
  * build(deps): bump proc-macro2 from 1.0.94 to 1.0.95 (#13945)
  * build(deps): bump rand from 0.9.0 to 0.9.1 (#13949)
  * build(deps): bump tj-actions/changed-files (#13950)
  * build(deps-dev): bump webpack from 5.99.5 to 5.99.6 in /web/app
    (#13952)
  * build(deps): bump signal-hook-registry from 1.4.2 to 1.4.5
    (#13954)
  * build(deps): bump the clap group with 2 updates (#13955)
  * build(deps): bump http-proxy-middleware from 2.0.7 to 2.0.9 in
    /web/app (#13957)
  * build(deps): bump softprops/action-gh-release from 2.2.1 to
    2.2.2 (#13956)
* Wed Apr 16 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 25.4.3:
  * build(deps): bump linkerd-extension-init from 0.1.3 to 0.1.4
    (#13943)
  * build(deps): bump codecov/codecov-action from 5.4.0 to 5.4.2
    (#13941)
  * fix(CLI): Check that the Gateway API version includes v1
    resources (#13938)
  * build(deps): bump h2 from 0.4.8 to 0.4.9 (#13939)
  * build(deps): bump cc from 1.2.18 to 1.2.19 (#13935)
  * build(deps): bump github.com/prometheus/client_golang (#13920)
  * build(deps): bump tj-actions/changed-files (#13936)
  * build(deps): bump anyhow from 1.0.97 to 1.0.98 (#13934)
  * build(deps): bump data-encoding from 2.8.0 to 2.9.0 (#13933)
  * build(deps-dev): bump webpack from 5.97.1 to 5.99.5 in /web/app
    (#13930)
  * build(deps): bump the clap group with 2 updates (#13932)
  * build(deps): bump github.com/prometheus/client_model from 0.6.1
    to 0.6.2 (#13931)
  * fix(CLI): Print specific command when prompting to install the
    Gateway API
  * build(deps): bump rustls from 0.23.25 to 0.23.26 (#13928)
  * build(deps): bump backon from 1.4.1 to 1.5.0 (#13919)
  * build(deps): bump helm.sh/helm/v3 from 3.17.2 to 3.17.3
    (#13921)
* Thu Apr 10 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 25.4.2:
  * build(deps): bump google.golang.org/grpc from 1.71.0 to 1.71.1
    (#13895)
  * build(deps): bump golang.org/x/tools from 0.31.0 to 0.32.0
    (#13909)
  * build(deps): bump github.com/linkerd/linkerd2-proxy-api
    (#13884)
  * build(deps): bump tj-actions/changed-files (#13917)
  * build(deps): bump cc from 1.2.17 to 1.2.18 (#13904)
  * build(deps): bump github.com/fsnotify/fsnotify from 1.8.0 to
    1.9.0 (#13907)
  * build(deps): bump golang.org/x/net from 0.37.0 to 0.39.0
    (#13910)
  * build(deps): bump errno from 0.3.10 to 0.3.11 (#13905)
  * build(deps): bump miniz_oxide from 0.8.7 to 0.8.8 (#13914)
  * build(deps): bump openssl-src from 300.4.2+3.4.1 to
    300.5.0+3.5.0 (#13913)
  * build(deps): bump hostname from 0.4.0 to 0.4.1 (#13915)
  * build(deps): bump smallvec from 1.14.0 to 1.15.0 (#13903)
  * build(deps): bump tokio from 1.44.1 to 1.44.2 (#13906)
  * build(deps): bump openssl from 0.10.71 to 0.10.72 (#13901)
  * build(deps): bump miniz_oxide from 0.8.5 to 0.8.7 (#13899)
* Wed Apr  2 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 25.4.1:
  * chore(ci): run policy tests against various Gateway API
    versions (#13893)
  * fix(policy-test): feature-gate experimental types in tests
    (#13896)
  * build(deps): bump the clap group with 2 updates (#13894)
  * feat(policy-test): conditionally compile experimental type
    tests (#13891)
  * chore(multicluster): update Prometheus configs and access
    policy to scrape new multicluster controllers (#13892)
  * build(deps): enable tracing feature in hyper-util (#13890)
  * fix(cli): check if installGatewayAPI is true before we error
    during CRD install (#13872)
  * proxy: v2.290.0 (#13889)
  * build(deps): bump iana-time-zone from 0.1.62 to 0.1.63 (#13885)
  * build(deps): bump tj-actions/changed-files (#13887)
  * feat(multicluster): add --only-controller flag to `linkerd mc
    unlink` (#13874)
  * build(deps): bump hyper-util from 0.1.10 to 0.1.11 (#13886)
  * build(deps): bump linkerd2-proxy-api from git to v0.16.0
    (#13883)
  * build(deps): bump event-listener-strategy from 0.5.3 to 0.5.4
    (#13868)
  * build(deps-dev): bump webpack-dev-server from 5.2.0 to 5.2.1 in
    /web/app (#13875)
  * build(deps-dev): bump @babel/runtime from 7.26.10 to 7.27.0 in
    /web/app (#13876)
  * build(deps-dev): bump sinon from 19.0.4 to 20.0.0 in /web/app
    (#13877)
  * build(deps-dev): bump @babel/eslint-parser in /web/app (#13878)
  * build(deps): bump @babel/eslint-plugin in /web/app (#13879)
  * build(deps): bump once_cell from 1.21.1 to 1.21.3 (#13880)
  * build(deps): bump darling from 0.20.10 to 0.20.11 (#13881)
  * build(deps): bump socket2 from 0.5.8 to 0.5.9 (#13882)
* Fri Mar 28 2025 opensuse_buildservice@ojkastl.de
- Update to version 25.3.4:
  * Bump Prometheus to `v2.55.1` (#13867)
  * build(deps): bump the clap group with 2 updates (#13866)
  * feat(CLI): Add errors for invalid Gateway API CRD states
    (#13834)
  * build(deps): bump pest_derive from 2.7.15 to 2.8.0 (#13860)
  * build(deps): bump delegate from 0.13.2 to 0.13.3 (#13861)
  * build(deps): bump pest from 2.7.15 to 2.8.0 (#13862)
  * build(deps): bump rustls-webpki from 0.103.0 to 0.103.1
    (#13863)
  * build(deps): bump cc from 1.2.16 to 1.2.17 (#13853)
  * build(deps): bump log from 0.4.26 to 0.4.27 (#13856)
  * build(deps): bump google.golang.org/protobuf from 1.36.5 to
    1.36.6 (#13855)
  * build(deps): bump iana-time-zone from 0.1.61 to 0.1.62 (#13857)
  * build(deps): bump tj-actions/changed-files (#13854)
  * build(deps): bump linkerd-extension-init from 0.1.2 to 0.1.3
    (#13833)
  * build(deps): bump actions/upload-artifact from 4.6.1 to 4.6.2
    (#13836)
  * build(deps): bump Swatinem/rust-cache from 2.7.7 to 2.7.8
    (#13838)
  * build(deps): bump actions/download-artifact from 4.2.0 to 4.2.1
    (#13839)
  * chore(dependabot): group kubert updates (#13842)
  * build(deps): bump kubert from 0.23 to 0.24 (#13843)
  * chore(deps): remove unused k8s-gateway-api dependency (#13844)
  * build(deps): bump tj-actions/changed-files (#13837)
* Thu Mar 20 2025 opensuse_buildservice@ojkastl.de
- Update to version 25.3.3:
  no CLI-related changes in the changelog (other than dependencies)
  * build(deps): bump windows-link from 0.1.0 to 0.1.1 (#13828)
  * build(deps): bump actions/download-artifact from 4.1.9 to 4.2.0
    (#13830)
  * build(deps): bump actions/setup-go from 5.3.0 to 5.4.0 (#13831)
  * build(deps): bump github.com/containerd/containerd from 1.7.24
    to 1.7.27 (#13816)
  * build(deps): bump tj-actions/changed-files (#13820)
  * build(deps): bump rustls from 0.23.23 to 0.23.25 (#13817)
  * build(deps): bump http-body-util from 0.1.2 to 0.1.3 (#13818)
  * build(deps): bump async-trait from 0.1.86 to 0.1.88 (#13819)
  * build(deps): bump @babel/eslint-plugin in /web/app (#13806)
  * build(deps): bump libc from 0.2.170 to 0.2.171 (#13811)
  * build(deps): bump dtoa from 1.0.9 to 1.0.10 (#13810)
  * build(deps): bump foldhash from 0.1.4 to 0.1.5 (#13809)
  * build(deps): bump hyper-http-proxy from 1.0.0 to 1.1.0 (#13808)
  * build(deps): bump rustversion from 1.0.19 to 1.0.20 (#13807)
  * build(deps): bump extractions/setup-just from 2.0.0 to 3.0.0
    (#13812)
  * build(deps): bump github.com/prometheus/common from 0.62.0 to
    0.63.0 (#13791)
  * build(deps): bump helm.sh/helm/v3 from 3.17.1 to 3.17.2
    (#13792)
  * build(deps): bump itoa from 1.0.14 to 1.0.15 (#13794)
  * build(deps): bump once_cell from 1.21.0 to 1.21.1 (#13796)
  * build(deps): bump tj-actions/changed-files from 45.0.7 to
    45.0.8 (#13798)
  * build(deps): bump tokio-util from 0.7.13 to 0.7.14 (#13797)
  * build(deps): bump tokio from 1.43.0 to 1.44.1 (#13793)
* Fri Mar 14 2025 opensuse_buildservice@ojkastl.de
- Update to version 25.3.2:
  no CLI-related changes in the changelog (other than dependencies)
* Fri Mar  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 25.3.1:
  no CLI-related changes in the changelog (other than dependencies)
* Fri Feb 28 2025 opensuse_buildservice@ojkastl.de
- Update to version 25.2.3:
  no CLI-related changes in the changelog
* Thu Feb 20 2025 opensuse_buildservice@ojkastl.de
- Update to version 25.2.2:
  no CLI-related changes in the changelog
* Thu Feb 13 2025 opensuse_buildservice@ojkastl.de
- Update to version 25.2.1:
  * fix(cli): Don't require gateway CRDs in linkerd install
* Thu Jan 23 2025 opensuse_buildservice@ojkastl.de
- Update to version 25.1.2:
  no CLI-related changes in changelog
* Fri Jan 17 2025 opensuse_buildservice@ojkastl.de
- Update to version 25.1.1:
  no CLI-related changes in changelog
* Wed Nov 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.11.8:
  no CLI-related changes in changelog
* Tue Nov 26 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.11.7:
  no CLI-related changes in changelog
* Tue Nov 26 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.11.6:
  no CLI-related changes in changelog
* Tue Nov 26 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.11.5:
  * feat(cli): add check for link version (#13376)
* Wed Nov 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.11.4:
  no CLI-related changes in changelog
* Fri Nov 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.11.3:
  no CLI-related changes in changelog
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.11.2:
  no CLI-related changes in changelog
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.11.1:
  no CLI-related changes in changelog
* Thu Oct 31 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.10.5:
  no CLI-related changes in changelog
* Thu Oct 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.10.4:
  no CLI-related changes in changelog
* Fri Oct 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.10.3:
  no CLI-related changes in changelog
* Fri Oct 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.10.2:
  CLI-related changes:
  * Relax mc validations in the CLI to avoid errors (#13151)
* Sun Oct  6 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.10.1:
  no CLI-related changes in changelog
* Fri Sep 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.9.3:
  no CLI-related changes in changelog
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.9.2:
  no CLI-related changes in changelog
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.9.1:
  no CLI-related changes in changelog
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 24.8.3:
  no CLI-related changes in changelog
* Fri Aug 16 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package linkerd-cli-edge following the edge releases of
  linkerd2
